

module c5gt_fpga_bup_top
(
   input                clkin_50,
   input                cpu_resetn,
   
   output               enet_mdc,
   inout                enet_mdio,
   output               enet_resetn, // AT6 for revB
   input                enet_rx_clk,
   input                enet_rx_dv,
   input    [  3 : 0 ]  enet_rx_d,
   output               enet_gtx_clk,
   output               enet_tx_en,
   output   [  3 : 0 ]  enet_tx_d,
   
   output               flash_cen,
   output               flash_oen,
   output               flash_resetn,
   output               flash_wen,
   output   [ 26 : 0 ]  fm_a,
   inout    [ 15 : 0 ]  fm_d,
   output               flash_advn,
   output               flash_clk, 
	
	// lcd using opencore_i2c
   output               disp_i2c_scl,
   inout                disp_i2c_sda,
   
   input    [  7 : 0 ]  user_dipsw,
   input    [  2 : 0 ]  user_pb,
   output   [  7 : 0 ]  user_led,
	
/////////////////////////////////////////////////////////
   	//debug pll clocks:  
	output	  	pcie_led_x1, // out25led,  //  pcie_led_x1 AK19 
	output	  	pcie_led_x4 // out125led  //  pcie_led_x4 AD22 
/////////////////////////////////////////////////////////
   
);

wire              locked_from_the_enet_pll;
wire              mdio_oen_from_the_tse_mac;
wire              mdio_out_from_the_tse_mac;
wire              eth_mode_from_the_tse_mac;
wire              ena_10_from_the_tse_mac;
wire              enet_tx_125;
wire              enet_tx_25;
wire              enet_tx_2p5;
wire              tx_clk_to_the_tse_mac;
wire              tx_clk_to_the_tse_mac_g;
wire              global_resetn;
    wire                cpu_jtag_reset;
	wire                S_cpu_resetn;

    assign S_cpu_resetn = cpu_resetn && !cpu_jtag_reset;
	assign flash_resetn = S_cpu_resetn;
assign flash_advn   = 1'b0;
assign flash_clk    = 1'b0;


enet_gtx_clk_ddio_buffer   enet_gtx_clk_ddio_buffer_inst (
   .aclr       ( !S_cpu_resetn ),
   .datain_h   ( 1'b1 ),
   .datain_l   ( 1'b0 ),
   .outclock   ( tx_clk_to_the_tse_mac_g ), // tx_clk_to_the_tse_mac ),
   .dataout    ( enet_gtx_clk )
);
    
assign tx_clk_to_the_tse_mac =   ( eth_mode_from_the_tse_mac ) ? ( enet_tx_125 ) :  // GbE Mode = 125MHz clock
                                 ( ena_10_from_the_tse_mac ) ? ( enet_tx_2p5 ) :    // 10Mb Mode = 2.5MHz clock
                                 ( enet_tx_25 );                                    // 100Mb Mode = 25MHz clock

clkctrl clkctrl_inst0 (
        .inclk        (tx_clk_to_the_tse_mac  ),
        .outclk       (tx_clk_to_the_tse_mac_g)
        );
                        
assign enet_mdio = ( !mdio_oen_from_the_tse_mac ) ? ( mdio_out_from_the_tse_mac ) : ( 1'bz );

parameter MSB = 19; // PHY interface: need minimum 10ms delay for POR

    reg [MSB:0] epcount; // MSB was 15, now 19
    
    always @(posedge clkin_50)
    begin 
     if (S_cpu_resetn == 1'b0)
//     if (nios_resetn == 1'b0)
        epcount <= MSB + 1'b0;
      else
		if (epcount[MSB] == 1'b0)
			epcount <= epcount + 1;
		else
			epcount <= epcount;
    end
    
assign enet_resetn = !epcount[MSB-1];

///////////////////////////////////////////////////////
////// debug enet_pll outputs
reg [24:0] count25;
reg [27:0] count125;
  
always@(posedge enet_tx_25)
begin
  count25  <= count25 + 1;
  if(count25 == 25'h3ffffff)
    count25<= 25'h0000000;        
end

always@(posedge enet_tx_125)
begin
  count125 <= count125 + 1;
  if(count125 == 28'hfffffff)
    count125<= 28'h0000000;        
end

assign pcie_led_x1  = count25[24];  // 100mbs clock toggling
assign pcie_led_x4 = count125[27];  // 1Gbs   clock toggling
////////////////////////////////////////////////////////

c5gt_fpga_bup_qsys c5gt_fpga_bup_qsys_inst
(
   .clkin_50_clk                                       ( clkin_50 ),
   .enet_pll_outclk0_clk                               ( enet_tx_125 ),
   .enet_pll_outclk1_clk                               ( enet_tx_25 ),
   .enet_pll_outclk2_clk                               ( enet_tx_2p5 ),
   .merged_resets_in_reset_reset_n                     	  (S_cpu_resetn),
   .cpu_jtag_debug_module_reset_reset                     (cpu_jtag_reset),
   .dipsw_pio_out_1_export                             ( user_dipsw ),
   .button_pio_out_export                              ( user_pb ),
   .led_pio_out_export                                 ( user_led ),
	
   .opencores_i2c_lcd_export_scl_pad_io                (disp_i2c_scl),
   .opencores_i2c_lcd_export_sda_pad_io                (disp_i2c_sda),
   
   .cfi_flash_atb_bridge_0_out_tcm_address_out         ( fm_a ),
   .cfi_flash_atb_bridge_0_out_tcm_data_out            ( fm_d ),
   .cfi_flash_atb_bridge_0_out_tcm_read_n_out          ( flash_oen ),
   .cfi_flash_atb_bridge_0_out_tcm_chipselect_n_out    ( flash_cen ),
   .cfi_flash_atb_bridge_0_out_tcm_write_n_out         ( flash_wen ),	 
	
   // the_enet_pll
   .enet_pll_reset_reset                               (!S_cpu_resetn),
   .enet_pll_locked_export                             ( locked_from_the_enet_pll ),
   
   // the_tse_mac
   .tse_mac_mac_status_connection_ena_10               ( ena_10_from_the_tse_mac ),
   .tse_mac_mac_status_connection_eth_mode             ( eth_mode_from_the_tse_mac ),
   .tse_mac_mac_mdio_connection_mdc                    ( enet_mdc ),
   .tse_mac_mac_mdio_connection_mdio_in                ( enet_mdio ),
   .tse_mac_mac_mdio_connection_mdio_oen               ( mdio_oen_from_the_tse_mac ),
   .tse_mac_mac_mdio_connection_mdio_out               ( mdio_out_from_the_tse_mac ),
   .tse_mac_mac_rgmii_connection_rgmii_in              ( enet_rx_d ),
   .tse_mac_mac_rgmii_connection_rgmii_out             ( enet_tx_d ),
   .tse_mac_pcs_mac_rx_clock_connection_clk            ( enet_rx_clk ),
   .tse_mac_mac_rgmii_connection_rx_control            ( enet_rx_dv ),
   .tse_mac_mac_status_connection_set_1000             ( ),
   .tse_mac_mac_status_connection_set_10               ( ),
   .tse_mac_pcs_mac_tx_clock_connection_clk            ( tx_clk_to_the_tse_mac_g ), // tx_clk_to_the_tse_mac ),
   .tse_mac_mac_rgmii_connection_tx_control            ( enet_tx_en )
	
	
);

endmodule


	 
	 