/*
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!! You manually have to fix the HMC issue.
!! Open the uniphy top RTL(q_sys_fpga_sdram.v)
!! then, find the line that contains...
!! 	.mp_cmd_clk_1(1'b0),
!! change this to 
!! 	.mp_cmd_clk_1(mp_cmd_clk_0_clk),



		.mp_cmd_clk_1            (mp_cmd_clk_0_clk),                                                //        (terminated)
		.mp_cmd_reset_n_1        (mp_cmd_reset_n_0_reset_n),                                                //        (terminated)
		.mp_cmd_clk_2            (mp_cmd_clk_0_clk),                                                //        (terminated)
		.mp_cmd_reset_n_2        (mp_cmd_reset_n_0_reset_n),                                                //        (terminated)
		.mp_cmd_clk_3            (mp_cmd_clk_0_clk),                                                //        (terminated)
		.mp_cmd_reset_n_3        (mp_cmd_reset_n_0_reset_n),                                                //        (terminated)

		
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

This project is for revB board.
The differences in revA/B in this project is only the fpga_led_output[0] pin location.

Rev 0 : original code
Rev 1 : master_driver got changed. SDC got constrainged tighter

*/


module c5gt_ddr3 (
  input clk_50m_fpga,
  input CLKINBOT_P,	//100MHz for hmc
  input clkin_r_p, // for DDR3 smc
  

  input cpu_resetn,
  output [7:0] user_led,
  
   output  [13:0] ddr3a_a,
	output  [2:0] ddr3a_ba,
	output  ddr3a_clk_p,
	output  ddr3a_clk_n,
	output  ddr3a_cke,
	output  ddr3a_csn,
	output  ddr3a_rasn,
	output  ddr3a_casn,
	output  ddr3a_wen,
	output  ddr3a_resetn,
	output  ddr3a_odt,

	output  [4:0] ddr3a_dm,
	inout  [39:0] ddr3a_dq,
	inout  [4:0] ddr3a_dqs_p,
	inout  [4:0] ddr3a_dqs_n,
	
	output [13 : 0]	ddr3b_a,
	output [2 : 0]		ddr3b_ba,
	output ddr3b_casn,
	output ddr3b_clk_n,
	output ddr3b_clk_p,
	output ddr3b_cke,
	output ddr3b_csn,
	output [7 : 0]ddr3b_dm,
	inout [63:0]ddr3b_dq,
	inout [7 : 0]ddr3b_dqs_n,
	inout [7 : 0]ddr3b_dqs_p,
	output ddr3b_odt,
	output ddr3b_rasn,
	output ddr3b_resetn,
	output ddr3b_wen,
	
	
	
	input rzqin_1_5v // shared with hmc and smc
	
	

);


	wire hmc_cal_fail_mon;
	wire hmc_cal_success_mon;
	wire hmc_init_done_mon;
	wire hmc_error_mon ;
	wire hmc_status_mon;
	wire hmc_pass_mon;

	wire smc_cal_fail_mon;
	wire smc_cal_success_mon;
	wire smc_init_done_mon;
	wire smc_error_mon ;
	wire smc_status_mon;
	wire smc_pass_mon;


	wire [3:0]reset_int;
	issp issp (
		.probe({hmc_cal_fail_mon, hmc_cal_success_mon, hmc_init_done_mon, smc_cal_fail_mon, smc_cal_success_mon, smc_init_done_mon}),
		.source(reset_int)
	);


    q_sys u0 (
        .clk_50_clk                                  (clk_50m_fpga),
        .reset_50_reset_n                            (cpu_resetn & reset_int[0]),

        .oct_hmc_rzqin              (rzqin_1_5v),

        .memory_hmc_mem_a           (ddr3a_a),
        .memory_hmc_mem_ba          (ddr3a_ba),
        .memory_hmc_mem_ck          (ddr3a_clk_p),
        .memory_hmc_mem_ck_n        (ddr3a_clk_n),
        .memory_hmc_mem_cke         (ddr3a_cke),
        .memory_hmc_mem_cs_n        (ddr3a_csn),
        .memory_hmc_mem_dm          (ddr3a_dm),
        .memory_hmc_mem_ras_n       (ddr3a_rasn),
        .memory_hmc_mem_cas_n       (ddr3a_casn),
        .memory_hmc_mem_we_n        (ddr3a_wen),
        .memory_hmc_mem_reset_n     (ddr3a_resetn),
        .memory_hmc_mem_dq          (ddr3a_dq),
        .memory_hmc_mem_dqs         (ddr3a_dqs_p),
        .memory_hmc_mem_dqs_n       (ddr3a_dqs_n),
        .memory_hmc_mem_odt         (ddr3a_odt),

        .memory_smc_mem_a           (ddr3b_a),
        .memory_smc_mem_ba          (ddr3b_ba),
        .memory_smc_mem_ck          (ddr3b_clk_p),
        .memory_smc_mem_ck_n        (ddr3b_clk_n),
        .memory_smc_mem_cke         (ddr3b_cke),
        .memory_smc_mem_cs_n        (ddr3b_csn),
        .memory_smc_mem_dm          (ddr3b_dm),
        .memory_smc_mem_ras_n       (ddr3b_rasn),
        .memory_smc_mem_cas_n       (ddr3b_casn),
        .memory_smc_mem_we_n        (ddr3b_wen),
        .memory_smc_mem_reset_n     (ddr3b_resetn),
        .memory_smc_mem_dq          (ddr3b_dq),
        .memory_smc_mem_dqs         (ddr3b_dqs_p),
        .memory_smc_mem_dqs_n       (ddr3b_dqs_n),
        .memory_smc_mem_odt         (ddr3b_odt),


        .hmc_error_mon              (hmc_error_mon),
        .hmc_status_mon             (hmc_status_mon),
        .hmc_status_cal_fail_mon    (hmc_cal_fail_mon),
        .hmc_status_cal_success_mon (hmc_cal_success_mon),
        .hmc_status_init_done_mon   (hmc_init_done_mon),

        .smc_error_mon              (smc_error_mon),
        .smc_status_mon             (smc_status_mon),
        .smc_status_cal_fail_mon    (smc_cal_fail_mon),
        .smc_status_cal_success_mon (smc_cal_success_mon),
        .smc_status_init_done_mon   (smc_init_done_mon),

        .clk_hmc_clk                (CLKINBOT_P),
        .clk_smc_clk                (clkin_r_p),
        .tg_smc_reset_n             (reset_int[2]),
        .tg_hmc_reset_n             (reset_int[1]),
        .reset_hmc_reset_n          (cpu_resetn & reset_int[3]),
        .reset_smc_reset_n          (cpu_resetn & reset_int[3])

    );

	 
	 
	 

  // assigning subset of the 32-bit PIO value to LED outputs, the LEDs are active low so invert these in software first
   assign user_led[0] = !hmc_status_mon | hmc_cal_fail_mon;
   assign user_led[1] = hmc_error_mon;
   assign user_led[2] = !smc_status_mon | smc_cal_fail_mon;
   assign user_led[3] = smc_error_mon;
   assign user_led[7:4] = 4'b1111;
  
endmodule
