/*
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!! You manually have to fix the HMC issue.
!! Open the uniphy top RTL(q_sys_fpga_sdram.v)
!! then, find the line that contains...
!! 	.mp_cmd_clk_1(1'b0),
!! change this to 
!! 	.mp_cmd_clk_1(mp_cmd_clk_0_clk),
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

This project is for revB board.
The differences in revA/B in this project is only the fpga_led_output[0] pin location.
*/


module c5sx_SoC_HMC (
  input clk_50m_fpga,
  input CLKINBOT_P,	//100MHz
//  input clk_top,
  input cpu_resetn,
  output [7:0] user_led,
  
   output  [13:0] ddr3a_a,
	output  [2:0] ddr3a_ba,
	output  ddr3a_clk_p,
	output  ddr3a_clk_n,
	output  ddr3a_cke,
	output  ddr3a_csn,
	output  ddr3a_rasn,
	output  ddr3a_casn,
	output  ddr3a_wen,
	output  ddr3a_resetn,
	output  ddr3a_odt,
	input  rzqin_1_5v,
	output  [4:0] ddr3a_dm,
	inout  [39:0] ddr3a_dq,
	inout  [4:0] ddr3a_dqs_p,
	inout  [4:0] ddr3a_dqs_n

);


  // internal wire to loop the FPGA LED outputs back into the PIO so that they can be read back by software
	wire [31:0] fpga_internal_led;

	wire cal_fail_mon         ;
	wire cal_success_mon      ;
	wire init_done_mon        ;
	wire error_mon ;
	wire status_mon;
	wire pass_mon;

	wire reset_int;
	issp issp (
		.probe({error_mon, status_mon, cal_fail_mon, cal_success_mon, init_done_mon}),
		.source(reset_int)
	);

	q_sys u0 (
        .refclk_clk                        (CLKINBOT_P),
		.reset_50_reset_n                    (cpu_resetn & reset_int),
		.clk_50_clk                          (clk_50m_fpga),
		
    .fpga_memory_mem_a                     (ddr3a_a),
		.fpga_memory_mem_ba                  (ddr3a_ba),
		.fpga_memory_mem_ck                  (ddr3a_clk_p),
		.fpga_memory_mem_ck_n                (ddr3a_clk_n),
		.fpga_memory_mem_cke                 (ddr3a_cke),
		.fpga_memory_mem_cs_n                (ddr3a_csn),
		.fpga_memory_mem_dm                  (ddr3a_dm),
		.fpga_memory_mem_ras_n               (ddr3a_rasn),
		.fpga_memory_mem_cas_n               (ddr3a_casn),
		.fpga_memory_mem_we_n                (ddr3a_wen),
		.fpga_memory_mem_reset_n             (ddr3a_resetn),
		.fpga_memory_mem_dq                  (ddr3a_dq),
		.fpga_memory_mem_dqs                 (ddr3a_dqs_p),
		.fpga_memory_mem_dqs_n               (ddr3a_dqs_n),
		.fpga_memory_mem_odt                 (ddr3a_odt),
		.fpga_memory_oct_rzqin               (rzqin_1_5v),
		
        .master_driver_msgdma_0_conduit_end_error_mon  (error_mon),
        .master_driver_msgdma_0_conduit_end_status_mon (status_mon),
        .msgdma_0_status_mon_out_cal_fail_mon          (cal_fail_mon),
        .msgdma_0_status_mon_out_cal_success_mon       (cal_success_mon),
        .msgdma_0_status_mon_out_init_done_mon         (init_done_mon)
		  
  );


  // assigning subset of the 32-bit PIO value to LED outputs, the LEDs are active low so invert these in software first
   assign user_led[0] = !status_mon | cal_fail_mon;
   assign user_led[1] = error_mon;
	assign user_led[7:2] = 2'b111111;
  
endmodule
