module c5gx_hsma (

//GPLL-CLK-----------------------------//8 pins
	input clk_50m_fpga,
	input CLK_100M_FPGA,

   output  [7:0] user_led,
   input          cpu_resetn,          //2.5V    //CPU Reset Pushbutton (TR=0)
                                              //must install 0-ohm resistor

// XCVR															 
	input refclk,
//	input refclk1_q2l_p, // 100MHz for revA
	input	[3:0]	hsma_rx_p, 
	output	[3:0]	hsma_tx_p, 

// CMOS	
	inout	[3:0]	hsma_d, 
	output			hsma_scl,
	inout			hsma_sda,

	
// LVDS	
   input   [2:2]       	hsma_clk_in_p,      //LVDS    //Primary Source-Sync CLKIN
	output [2:2] 			hsma_clk_out_p,
	input [16:0] hsma_rx_d_p,
	output [16:0] hsma_tx_d_p
	);

	
	wire [135:0] tx_in_sig;
	wire [135:0] rx_out_sig;
	wire rx_locked_sig;
	wire tx_locked_sig;
	wire tx_coreclock_sig;
	wire rx_outclock_sig;
	wire in_ready;
	wire out_vaild;
//	wire CLK_125_P_inst;
	wire clk_80mhz;
	wire sample_clk;
	
	wire pll_clk;	 
	clkcnt clkcnt (
		.inclk(CLK_100M_FPGA),
		.outclk(pll_clk)
	);	

 	wire [31:0] tx_out_data;
	wire xcvr_lock0,xcvr_lock1,xcvr_lock2,xcvr_lock3;
	wire xcvr_lock;
	assign xcvr_lock=xcvr_lock0;
	wire xcvr_0_error_mon, xcvr_0_status_mon, xcvr_1_error_mon, xcvr_1_status_mon, xcvr_2_error_mon, xcvr_2_status_mon, xcvr_3_error_mon, xcvr_3_status_mon;
	wire lvds_0_error_mon, lvds_0_status_mon, lvds_1_error_mon, lvds_1_status_mon, lvds_2_error_mon, lvds_2_status_mon;
	wire cmos_0_error_mon, cmos_0_status_mon;

    q_sys u0 (
        .clk_100_clk                                       (clk_50m_fpga),
        .clk_100_reset_reset_n                             (cpu_resetn),

		  
//        .xcvr_0_xcvr_custom_phy_0_pll_ref_clk_clk          (refclk1_q2l_p),
        .xcvr_0_xcvr_custom_phy_0_pll_ref_clk_clk          (refclk),
        .xcvr_0_xcvr_custom_phy_0_rx_serial_data_export    (hsma_rx_p[0]),
        .xcvr_0_xcvr_custom_phy_0_tx_serial_data_export    (hsma_tx_p[0]),
        .xcvr_0_xcvr_custom_phy_0_pll_locked_export        (xcvr_lock0),  
	     .xcvr_0_xcvr_custom_phy_1_pll_ref_clk_clk          (refclk),
        .xcvr_0_xcvr_custom_phy_1_rx_serial_data_export    (hsma_rx_p[1]),
        .xcvr_0_xcvr_custom_phy_1_tx_serial_data_export    (hsma_tx_p[1]),
        .xcvr_0_xcvr_custom_phy_1_pll_locked_export        (xcvr_lock1),	  
	     .xcvr_0_xcvr_custom_phy_2_pll_ref_clk_clk          (refclk),
        .xcvr_0_xcvr_custom_phy_2_rx_serial_data_export    (hsma_rx_p[2]),
        .xcvr_0_xcvr_custom_phy_2_tx_serial_data_export    (hsma_tx_p[2]),
        .xcvr_0_xcvr_custom_phy_2_pll_locked_export        (xcvr_lock2),	 
	     .xcvr_0_xcvr_custom_phy_3_pll_ref_clk_clk          (refclk),
        .xcvr_0_xcvr_custom_phy_3_rx_serial_data_export    (hsma_rx_p[3]),
        .xcvr_0_xcvr_custom_phy_3_tx_serial_data_export    (hsma_tx_p[3]),
        .xcvr_0_xcvr_custom_phy_3_pll_locked_export        (xcvr_lock3),	 		  
		  

        .cmos_0_data_pattern_generator_0_pattern_out_data  ({tx_out_data[31:3], hsma_scl,hsma_d[2],hsma_d[0]}),
        .cmos_0_data_pattern_generator_0_pattern_out_valid (tx_out_valid),
        .cmos_0_data_pattern_generator_0_pattern_out_ready (rx_in_ready),
        .cmos_0_data_pattern_checker_0_pattern_in_data     ({tx_out_data[31:3], hsma_sda,hsma_d[3],hsma_d[1]}),
        .cmos_0_data_pattern_checker_0_pattern_in_valid    (tx_out_valid),
        .cmos_0_data_pattern_checker_0_pattern_in_ready    (rx_in_ready),
		  
		  
//        .lvds_0_tx_clk_in_clk_clk                          (tx_coreclock_sig),
//        .lvds_0_rx_clk_in_clk_clk                          (rx_outclock_sig),
        .lvds_0_tx_clk                                     (tx_coreclock_sig),
        .lvds_0_rx_clk                                     (rx_outclock_sig),
        .lvds_0_data_pattern_generator_0_pattern_out_data  (tx_in_sig[31:0]),
        .lvds_0_data_pattern_generator_0_pattern_out_ready (tx_locked_sig),
        .lvds_0_data_pattern_checker_0_pattern_in_data     (rx_out_sig[31:0]),
        .lvds_0_data_pattern_checker_0_pattern_in_valid    (rx_locked_sig),
        .lvds_0_data_pattern_generator_1_pattern_out_data  (tx_in_sig[71:32]),
        .lvds_0_data_pattern_generator_1_pattern_out_ready (tx_locked_sig),
        .lvds_0_data_pattern_checker_1_pattern_in_data     (rx_out_sig[71:32]),
        .lvds_0_data_pattern_checker_1_pattern_in_valid    (rx_locked_sig),
        .lvds_0_data_pattern_generator_2_pattern_out_data  (tx_in_sig[135:72]),
        .lvds_0_data_pattern_generator_2_pattern_out_ready (tx_locked_sig),
        .lvds_0_data_pattern_checker_2_pattern_in_data     (rx_out_sig[135:72]),
        .lvds_0_data_pattern_checker_2_pattern_in_valid    (rx_locked_sig),
		  
		  
		  .lvds_0_data_pattern_checker_0_pattern_in_ready    (in_ready),
        .lvds_0_data_pattern_generator_0_pattern_out_valid (out_valid),
		  .lvds_0_data_pattern_checker_1_pattern_in_ready    (in_ready),
        .lvds_0_data_pattern_generator_1_pattern_out_valid (out_valid),
		  .lvds_0_data_pattern_checker_2_pattern_in_ready    (in_ready),
        .lvds_0_data_pattern_generator_2_pattern_out_valid (out_valid),
		 
		  
		  
		  
		  
		  
		  
		  
        .clk_50_clk                                        (clk_50m_fpga),
        .reset_50_reset_n                                  (cpu_resetn),
		  
		  
        .xcvr_0_tester_0_master_driver_com_0_conduit_end_lock       (xcvr_lock),
        .xcvr_0_tester_0_master_driver_com_0_conduit_end_error_mon  (xcvr_0_error_mon),
        .xcvr_0_tester_0_master_driver_com_0_conduit_end_status_mon (xcvr_0_status_mon),
        .xcvr_0_tester_1_master_driver_com_0_conduit_end_lock       (xcvr_lock),
        .xcvr_0_tester_1_master_driver_com_0_conduit_end_error_mon  (xcvr_1_error_mon),
        .xcvr_0_tester_1_master_driver_com_0_conduit_end_status_mon (xcvr_1_status_mon),
        .xcvr_0_tester_2_master_driver_com_0_conduit_end_lock       (xcvr_lock),
        .xcvr_0_tester_2_master_driver_com_0_conduit_end_error_mon  (xcvr_2_error_mon),
        .xcvr_0_tester_2_master_driver_com_0_conduit_end_status_mon (xcvr_2_status_mon),
        .xcvr_0_tester_3_master_driver_com_0_conduit_end_lock       (xcvr_lock),
        .xcvr_0_tester_3_master_driver_com_0_conduit_end_error_mon  (xcvr_3_error_mon),
        .xcvr_0_tester_3_master_driver_com_0_conduit_end_status_mon (xcvr_3_status_mon),
        .lvds_0_master_driver_com_2_conduit_end_lock                (rx_locked_sig),
        .lvds_0_master_driver_com_2_conduit_end_error_mon           (lvds_2_error_mon),
        .lvds_0_master_driver_com_2_conduit_end_status_mon          (lvds_2_status_mon),
        .lvds_0_master_driver_com_1_conduit_end_lock                (rx_locked_sig),
        .lvds_0_master_driver_com_1_conduit_end_error_mon           (lvds_1_error_mon),
        .lvds_0_master_driver_com_1_conduit_end_status_mon          (lvds_1_status_mon),
        .lvds_0_master_driver_com_0_conduit_end_lock                (rx_locked_sig),
        .lvds_0_master_driver_com_0_conduit_end_error_mon           (lvds_0_error_mon),
        .lvds_0_master_driver_com_0_conduit_end_status_mon          (lvds_0_status_mon),
        .cmos_0_master_driver_com_0_conduit_end_lock                (1),
        .cmos_0_master_driver_com_0_conduit_end_error_mon           (cmos_0_error_mon),
        .cmos_0_master_driver_com_0_conduit_end_status_mon          (cmos_0_status_mon)
		  
		  
    );


	 
	 

	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	
	LVDSTX	lvdstx_inst (
		.pll_areset ( !cpu_resetn ),
		.tx_in ( tx_in_sig ), // 136bit
		.tx_inclock ( CLK_100M_FPGA ),
		.tx_coreclock ( tx_coreclock_sig ), // used for internal locig   750/8 = 125MHz
		.tx_locked ( tx_locked_sig ),
		.tx_out ( hsma_tx_d_p ), // 17bits  runs at 750MHz
		.tx_outclock(tx_outclock_sig)
	);
	
	assign hsma_clk_out_p[2] = tx_outclock_sig;

	wire [16:0] rx_channel_data_align;
	issp issp (
		.probe(0),
		.source(rx_channel_data_align) // 17bits
	);
	
	LVDSRX	lvdsrx_inst (
		.pll_areset ( !cpu_resetn),
		.rx_in ( hsma_rx_d_p ), //17bits
		.rx_channel_data_align(rx_channel_data_align), //17bits control signal
		.rx_inclock ( CLK_100M_FPGA ), // coming from pin
		.rx_locked ( rx_locked_sig ),
		.rx_out ( rx_out_sig ), // 72bits
		.rx_outclock ( rx_outclock_sig )
	);	
	
	
	assign user_led[0] = xcvr_0_status_mon | xcvr_1_status_mon | xcvr_2_status_mon | xcvr_3_status_mon | xcvr_0_error_mon | xcvr_1_error_mon | xcvr_2_error_mon | xcvr_3_error_mon;
	assign user_led[1] = lvds_0_status_mon | lvds_1_status_mon | lvds_2_status_mon | lvds_0_error_mon | lvds_1_error_mon | lvds_2_error_mon;
	assign user_led[2] = cmos_0_status_mon | cmos_0_error_mon;
	assign user_led[7:3] = 5'b11111;
	
endmodule
