derive_pll_clocks


#**************************************************************
# Create Clock
#**************************************************************
# 80MHz => 12.5ns
create_clock -name virtual_clock_lvds -period 10
create_clock -name {hsma_clk_in_p} -period 10 -waveform { 0.000 5 } [get_ports {hsma_clk_in_p}] -add
#**************************************************************
# Set Input Delay
#**************************************************************
set_input_delay -clock [get_clocks virtual_clock_lvds] -clock_fall -max 0.200 [get_ports hsma_rx_d_p*] -add_delay
set_input_delay -clock [get_clocks virtual_clock_lvds] -clock_fall -min -0.200 [get_ports hsma_rx_d_p*] -add_delay


create_clock -name {CLK_125_P} -period 8.000 -waveform {0 4} {CLK_125_P}
create_clock -name {hsma_clk_in_p[2]} -period 8.000 -waveform {0 4} {hsma_clk_in_p[2]}
create_clock -name {CLK_100M_FPGA} -period 10.000 -waveform {0 5} {CLK_100M_FPGA}
create_clock -name {clk_50m_fpga} -period 20.000 -waveform {0 10} {clk_50m_fpga}
create_clock -name {refclk} -period 10.000 -waveform {0 5} {refclk}

create_clock -name {altera_reserved_tck} -period 20.800 -waveform { 0.000 10.400 } [get_ports { altera_reserved_tck }]
set_input_delay -clock altera_reserved_tck 5 [get_ports altera_reserved_tdi]
set_input_delay -clock altera_reserved_tck 5 [get_ports altera_reserved_tms]
set_output_delay -clock altera_reserved_tck -clock_fall -max 5 [get_ports altera_reserved_tdo]






## setting system clk, which is 50MHz as entire system clk
set system_clock [get_pins {*|*cmos_0|master_driver_com*|slow_clk_int[0]|clk}]


### setting CLK for CMOS interface
create_clock -name slow_clk_sample -period 40.000 -waveform {0 20} {*|*|frequency_counter*|slow_clk}
create_generated_clock -name slow_clk_cmos -source $system_clock  -divide_by 32 {*|*cmos_0|master_driver_com*|slow_clk_int[4]}


create_generated_clock -name slow_clk_freq1 -source [get_ports clk_50m_fpga] -divide_by 2 {q_sys:u0|q_sys_cmos_0:cmos_0|freq_counter:freq_counter_0|slow_clk}
set_false_path -from * -to [get_clocks {slow_clk_freq1}]
set_false_path -from [get_clocks {slow_clk_freq1}] -to  *


### setting CLK for LVDS interface
create_generated_clock -name slow_clk_lvds0 -source $system_clock  -divide_by 32 {*|*lvds_0|*master_driver_com_0|slow_clk_int[4]}
create_generated_clock -name slow_clk_lvds1 -source $system_clock  -divide_by 32 {*|*lvds_0|*master_driver_com_1|slow_clk_int[4]}
create_generated_clock -name slow_clk_lvds2 -source $system_clock  -divide_by 32 {*|*lvds_0|*master_driver_com_2|slow_clk_int[4]}




create_generated_clock -name slow_clk_freq2 -source [get_ports clk_50m_fpga] -divide_by 2 {q_sys:u0|q_sys_lvds_0:lvds_0|freq_counter:freq_counter_0|slow_clk}
set_false_path -from * -to [get_clocks {slow_clk_freq2}]
set_false_path -from [get_clocks {slow_clk_freq2}] -to  *
create_generated_clock -name slow_clk_freq3 -source [get_ports clk_50m_fpga] -divide_by 2 {q_sys:u0|q_sys_lvds_0:lvds_0|freq_counter:freq_counter_1|slow_clk}
set_false_path -from * -to [get_clocks {slow_clk_freq3}]
set_false_path -from [get_clocks {slow_clk_freq3}] -to  *
create_generated_clock -name slow_clk_freq4 -source [get_ports clk_50m_fpga] -divide_by 2 {q_sys:u0|q_sys_lvds_0:lvds_0|freq_counter:freq_counter_2|slow_clk}
set_false_path -from * -to [get_clocks {slow_clk_freq4}]
set_false_path -from [get_clocks {slow_clk_freq4}] -to  *


### setting CLK for LVDS interface
create_generated_clock -name slow_clk_xcvr0 -source $system_clock  -divide_by 32 {*|*|*tester_0|master_driver_com:master_driver_com_0|slow_clk_int[4]}
create_generated_clock -name slow_clk_xcvr1 -source $system_clock  -divide_by 32 {*|*|*tester_1|master_driver_com:master_driver_com_0|slow_clk_int[4]}
create_generated_clock -name slow_clk_xcvr2 -source $system_clock  -divide_by 32 {*|*|*tester_2|master_driver_com:master_driver_com_0|slow_clk_int[4]}
create_generated_clock -name slow_clk_xcvr3 -source $system_clock  -divide_by 32 {*|*|*tester_3|master_driver_com:master_driver_com_0|slow_clk_int[4]}





create_generated_clock -name slow_clk_freq5 -source [get_ports clk_50m_fpga] -divide_by 2 {q_sys:u0|q_sys_xcvr_0:xcvr_0|q_sys_xcvr_0_tester_0:tester_0|freq_counter:freq_counter_0|slow_clk}
set_false_path -from * -to [get_clocks {slow_clk_freq5}]
set_false_path -from [get_clocks {slow_clk_freq5}] -to  *
create_generated_clock -name slow_clk_freq6 -source [get_ports clk_50m_fpga] -divide_by 2 {q_sys:u0|q_sys_xcvr_0:xcvr_0|q_sys_xcvr_0_tester_1:tester_1|freq_counter:freq_counter_0|slow_clk}
set_false_path -from * -to [get_clocks {slow_clk_freq6}]
set_false_path -from [get_clocks {slow_clk_freq6}] -to  *
create_generated_clock -name slow_clk_freq7 -source [get_ports clk_50m_fpga] -divide_by 2 {q_sys:u0|q_sys_xcvr_0:xcvr_0|q_sys_xcvr_0_tester_2:tester_2|freq_counter:freq_counter_0|slow_clk}
set_false_path -from * -to [get_clocks {slow_clk_freq7}]
set_false_path -from [get_clocks {slow_clk_freq7}] -to  *
create_generated_clock -name slow_clk_freq8 -source [get_ports clk_50m_fpga] -divide_by 2 {q_sys:u0|q_sys_xcvr_0:xcvr_0|q_sys_xcvr_0_tester_3:tester_3|freq_counter:freq_counter_0|slow_clk}
set_false_path -from * -to [get_clocks {slow_clk_freq8}]
set_false_path -from [get_clocks {slow_clk_freq8}] -to  *


## cmos interface is very slow
set_false_path -from hsma_d[*] -to *
set_false_path -from hsma_sda -to *
set_false_path -from * -to hsma_scl
set_false_path -from * -to hsma_d[*]


set_false_path -from slow_clk_* -to *
set_false_path -from * -to slow_clk_*

set_false_path -from clk_50m_fpga* -to *
set_false_path -from * -to clk_50m_fpga*


set_false_path -from [get_ports {cpu_resetn}]


set_false_path -from * -to {sld_signaltap:auto_signaltap_0*}
set_false_path -from {sld_signaltap:auto_signaltap_0*} -to *


set_false_path -from [get_clocks {lvdsrx_inst|ALTLVDS_RX_component|auto_generated|pll_sclk~PLL_OUTPUT_COUNTER|divclk}] -to [get_clocks {pll|pll_inst|altera_pll_i|general[0].gpll~PLL_OUTPUT_COUNTER|divclk}]
set_false_path -from [get_clocks {pll|pll_inst|altera_pll_i|general[0].gpll~PLL_OUTPUT_COUNTER|divclk}] -to [get_clocks {lvdstx_inst|ALTLVDS_TX_component|auto_generated|pll_sclk~PLL_OUTPUT_COUNTER|divclk}]
set_false_path -from [get_clocks {CLK_125_P}] -to [get_clocks {lvdstx_inst|ALTLVDS_TX_component|auto_generated|pll_sclk~PLL_OUTPUT_COUNTER|divclk}]
set_false_path -from [get_clocks {u0|xcvr_custom_phy_0|A5|transceiver_core|gen.av_xcvr_native_insts[2].gen_bonded_group.av_xcvr_native_inst|inst_av_pcs|ch[0].inst_av_pcs_ch|inst_av_hssi_8g_rx_pcs|wys|rcvdclkpma}] -to [get_clocks {CLK_125_P}]


set_false_path -from {q_sys:u0|q_sys_tester_3:tester_3|altera_reset_controller:rst_controller|altera_reset_synchronizer:alt_rst_sync_uq1|altera_reset_synchronizer_int_chain_out*} -to {q_sys:u0|q_sys_tester_3:tester_3*}
set_false_path -from {q_sys:u0|q_sys_tester_1:tester_1|altera_reset_controller:rst_controller|altera_reset_synchronizer:alt_rst_sync_uq1|altera_reset_synchronizer_int_chain_out*} -to {q_sys:u0|q_sys_tester_1:tester_1*}
set_false_path -from {q_sys:u0|q_sys_tester_2:tester_2|altera_reset_controller:rst_controller|altera_reset_synchronizer:alt_rst_sync_uq1|altera_reset_synchronizer_int_chain_out*} -to {q_sys:u0|q_sys_tester_2:tester_2*}
set_false_path -from {q_sys:u0|q_sys_tester_0:tester_0|altera_reset_controller:rst_controller|altera_reset_synchronizer:alt_rst_sync_uq1|altera_reset_synchronizer_int_chain_out*} -to {q_sys:u0|q_sys_tester_0:tester_0*}


set_false_path -from {q_sys:u0|q_sys_lvds_0:lvds_0|altera_reset_controller:rst_controller|altera_reset_synchronizer:alt_rst_sync_uq1|altera_reset_synchronizer_int_chain_out*} -to {q_sys:u0|q_sys_lvds_0:lvds_0*}


set_false_path -from * -to user_led[*]
set_false_path -from {altera_internal_jtag*} -to {altera_reserved_tdo}