module c5gt_hsmb (

//GPLL-CLK-----------------------------//8 pins
	input clk_50m_fpga,
	input CLK_100M_FPGA,
//	input clk_top1,
//	input clk_bot1,

   input          cpu_resetn,          //2.5V    //CPU Reset Pushbutton (TR=0)
                                              //must install 0-ohm resistor
   output  [7:0] user_led,

// XCVR															 
	input refclk,
	//xcvr
	input [3:0] hsmb_rx_p,
	output [3:0] hsmb_tx_p,

	output	[31:0]		hsmb_dq, 
	output			hsmb_c_n,
	output			hsmb_addr_cmd0,
	output			hsmb_clk_out_n1, 
	output			hsmb_clk_out_p1, 	
	output			hsmb_clk_out_n2, 
	output			hsmb_clk_out_p2,	
	output			hsmb_clk_out0,
	output			hsmb_scl,
	output			hsmb_wen,
	output			hsmb_c_p,


	input	[3:0]		hsmb_dm, 
	input	[3:0]		hsmb_dqs_p, 
	input	[15:0]		hsmb_a, 
	input	[3:0]		hsmb_dqs_n, 
	input	[3:0]		hsmb_ba, 
	input			hsmb_clk_in0,
	input			hsmb_clk_in_p1,
	input			hsmb_clk_in_n1,
	input			hsmb_clk_in_p2,
	input			hsmb_clk_in_n2,	
	input			hsmb_sda,
	input			hsmb_csn,
	input			hsmb_cke,
	input			hsmb_casn,
	input			hsmb_rasn
	
	
	);

	
	wire reset_int;
	issp issp (
		.source(reset_int)
	);	
	
	wire [49:0] data_in, data_out;

	assign data_in[49:41] = data_out[49:41];

	wire xcvr_lock0,xcvr_lock1,xcvr_lock2,xcvr_lock3;
	wire xcvr_lock;
	assign xcvr_lock = xcvr_lock0 & xcvr_lock1 & xcvr_lock2 & xcvr_lock3;
	wire xcvr_0_error_mon, xcvr_0_status_mon, xcvr_1_error_mon, xcvr_1_status_mon, xcvr_2_error_mon, xcvr_2_status_mon, xcvr_3_error_mon, xcvr_3_status_mon;
	wire cmos_0_error_mon, cmos_0_status_mon;
	
    q_sys u0 (
        .clk_100_clk                                       (clk_50m_fpga),
        .clk_100_reset_reset_n                             (cpu_resetn & reset_int),
		  
        .cmos_0_data_pattern_generator_0_pattern_out_valid (tx_out_valid),
        .cmos_0_data_pattern_generator_0_pattern_out_ready (rx_in_ready),
        .cmos_0_data_pattern_generator_0_pattern_out_data  (data_out),
        .cmos_0_data_pattern_checker_0_pattern_in_valid    (tx_out_valid),
        .cmos_0_data_pattern_checker_0_pattern_in_ready    (rx_in_ready),
        .cmos_0_data_pattern_checker_0_pattern_in_data     (data_in),
		  
        .xcvr_0_xcvr_custom_phy_0_pll_ref_clk_clk          (refclk),
        .xcvr_0_xcvr_custom_phy_0_rx_serial_data_export    (hsmb_rx_p[0]),
        .xcvr_0_xcvr_custom_phy_0_tx_serial_data_export    (hsmb_tx_p[0]),
        .xcvr_0_xcvr_custom_phy_0_pll_locked_export                 (xcvr_lock0),
		   .xcvr_0_xcvr_custom_phy_1_pll_ref_clk_clk          (refclk),
        .xcvr_0_xcvr_custom_phy_1_rx_serial_data_export    (hsmb_rx_p[1]),
        .xcvr_0_xcvr_custom_phy_1_tx_serial_data_export    (hsmb_tx_p[1]),
        .xcvr_0_xcvr_custom_phy_1_pll_locked_export                 (xcvr_lock1),
		   .xcvr_0_xcvr_custom_phy_2_pll_ref_clk_clk          (refclk),
        .xcvr_0_xcvr_custom_phy_2_rx_serial_data_export    (hsmb_rx_p[2]),
        .xcvr_0_xcvr_custom_phy_2_tx_serial_data_export    (hsmb_tx_p[2]),
        .xcvr_0_xcvr_custom_phy_2_pll_locked_export                 (xcvr_lock2),
		   .xcvr_0_xcvr_custom_phy_3_pll_ref_clk_clk          (refclk),
        .xcvr_0_xcvr_custom_phy_3_rx_serial_data_export    (hsmb_rx_p[3]),
        .xcvr_0_xcvr_custom_phy_3_tx_serial_data_export    (hsmb_tx_p[3]),
        .xcvr_0_xcvr_custom_phy_3_pll_locked_export                 (xcvr_lock3),
		  
		  
        .clk_50_clk                                        (clk_50m_fpga),
        .reset_50_reset_n                                  (cpu_resetn & reset_int),
		  
		  
        .xcvr_0_tester_0_master_driver_com_0_conduit_end_lock       (xcvr_lock),
        .xcvr_0_tester_0_master_driver_com_0_conduit_end_error_mon  (xcvr_0_error_mon),
        .xcvr_0_tester_0_master_driver_com_0_conduit_end_status_mon (xcvr_0_status_mon),
        .xcvr_0_tester_1_master_driver_com_0_conduit_end_lock       (xcvr_lock),
        .xcvr_0_tester_1_master_driver_com_0_conduit_end_error_mon  (xcvr_1_error_mon),
        .xcvr_0_tester_1_master_driver_com_0_conduit_end_status_mon (xcvr_1_status_mon),
        .xcvr_0_tester_2_master_driver_com_0_conduit_end_lock       (xcvr_lock),
        .xcvr_0_tester_2_master_driver_com_0_conduit_end_error_mon  (xcvr_2_error_mon),
        .xcvr_0_tester_2_master_driver_com_0_conduit_end_status_mon (xcvr_2_status_mon),
        .xcvr_0_tester_3_master_driver_com_0_conduit_end_lock       (xcvr_lock),
        .xcvr_0_tester_3_master_driver_com_0_conduit_end_error_mon  (xcvr_3_error_mon),
        .xcvr_0_tester_3_master_driver_com_0_conduit_end_status_mon (xcvr_3_status_mon),
		  
		  
		  
        .cmos_0_master_driver_com_0_conduit_end_lock                (1),
        .cmos_0_master_driver_com_0_conduit_end_error_mon           (cmos_0_error_mon),
        .cmos_0_master_driver_com_0_conduit_end_status_mon          (cmos_0_status_mon)
		  		  
    );

	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	 
	assign user_led[0] = xcvr_0_status_mon | xcvr_1_status_mon | xcvr_2_status_mon | xcvr_3_status_mon | xcvr_0_error_mon | xcvr_1_error_mon | xcvr_2_error_mon | xcvr_3_error_mon;
	assign user_led[1] = cmos_0_status_mon | cmos_0_error_mon;
	assign user_led[7:2] = 6'b111111;

	
	assign	data_in[40:0]	=
		{     
			hsmb_rasn               ,
			hsmb_casn               ,
			hsmb_dm[0]              ,
			hsmb_a[0]               ,
			hsmb_a[1]               ,
			hsmb_a[2]               ,
			hsmb_a[3]               ,
			hsmb_a[4]               ,
			hsmb_dqs_p[0]           ,
			hsmb_dqs_n[0]           ,
			hsmb_dm[1]              ,
			hsmb_a[5]               ,
			hsmb_a[6]               ,
			hsmb_a[7]               ,
			hsmb_a[8]               ,
			hsmb_a[9]               ,
			hsmb_dqs_p[1]           ,
			hsmb_dqs_n[1]	        ,
			hsmb_clk_in_p1		,
			hsmb_clk_in_n1		,
			hsmb_dm[2]              ,
			hsmb_a[10]              ,
			hsmb_a[11]              ,
			hsmb_a[12]              ,
			hsmb_a[13]              ,
			hsmb_a[14]              ,
			hsmb_dqs_p[2]           ,
			hsmb_dqs_n[2]		,
			hsmb_dm[3]              ,
			hsmb_a[15]              ,
			hsmb_ba[0]              ,
			hsmb_ba[1]              ,
			hsmb_ba[2]              ,
			hsmb_ba[3]              ,
			hsmb_dqs_p[3]           ,
			hsmb_dqs_n[3]           ,
			hsmb_cke                ,
			hsmb_csn		, 
			hsmb_clk_in_p2          ,
			hsmb_clk_in_n2          ,   			
			hsmb_sda
		};
			
		assign
		{     			
			hsmb_wen    		,
			hsmb_addr_cmd0    	,
			hsmb_dq[0]              ,
			hsmb_dq[1]              ,
			hsmb_dq[2]              ,
			hsmb_dq[3]              ,
			hsmb_dq[4]              ,
			hsmb_dq[5]              ,
			hsmb_dq[6]              ,
			hsmb_dq[7]              ,
			hsmb_dq[8]              ,
			hsmb_dq[9]              ,
			hsmb_dq[10]             ,
			hsmb_dq[11]             ,
			hsmb_dq[12]             ,
			hsmb_dq[13]             ,
			hsmb_dq[14]             ,
			hsmb_dq[15]             ,
			hsmb_clk_out_p1         ,
			hsmb_clk_out_n1         ,
			hsmb_dq[16]             ,
			hsmb_dq[17]             ,
			hsmb_dq[18]             ,
			hsmb_dq[19]             ,
			hsmb_dq[20]             ,
			hsmb_dq[21]             ,
			hsmb_dq[22]             ,
			hsmb_dq[23]             ,
			hsmb_dq[24]             ,
			hsmb_dq[25]             ,
			hsmb_dq[26]             ,
			hsmb_dq[27]             ,
			hsmb_dq[28]             ,
			hsmb_dq[29]             ,
			hsmb_dq[30]             ,
			hsmb_dq[31]		,       
			hsmb_c_p,							//hsmb_qvld               ,
			hsmb_c_n,							//hsmb_odt                ,
			hsmb_clk_out_p2		,
			hsmb_clk_out_n2		, 
			hsmb_scl                ,
			
		}	=	 data_out[40:0];  	
	
endmodule
