#!/bin/bash
#
# usage: ./restore.sh
#
#
# This directory contains the files used to build the BUP restore flash object files. 
#
# Build_restore.sh script commands may be run individually at a unix, linux, or Nios II EDS command shell.
#
#
# c5gt_fpga_bup hardware sof files from the project directories are converted
# using Nios II Tool sof2flash to attain flash files:
#
# sof2flash --offset=0x0020000 --input=c5gt_fpga_bup.sof 	  --output=c5gt_fpga_bup.flash
#
# c5gt_fpga_bup software - run make flash from the app\web_server dir 
# after running make to build software elf
#
# make flash
#
#
# actual rebuilding script of restore files can happen here for the end user:
#
# For eventual memory map - cat flash files for each ext_flash die (device is dual die with distinct CFI tables
#
#

echo "
Building restore flash file for lower and upper flash dies...

cat boot_code.flash pfl_bits.flash c5gt_fpga_bup.flash c5gt_html.flash ext_flash.flash > temp_restore.flash
"

cat boot_code.flash pfl_bits.flash c5gt_fpga_bup.flash c5gt_html.flash ext_flash.flash > temp_restore.flash

echo " 
Deleting unnecessary s-records within the flash files post-concatenation...

sed '/^S[05789]/ d' temp_restore.flash > restore_c5gt_fpga_bup.flash 
"

sed '/^S[05789]/ d' temp_restore.flash > restore_c5gt_fpga_bup.flash 

echo " 
Deleting temp file...
rm -f temp_restore.flash
"

rm -f temp_restore.flash


echo "
Done building restore flash files!
"

#
# To restore flash after building the restore files, follow instructions as specified in  
# the User's Guide, chapter entitled: "Restoring the Flash Device with the Factory Settings"
#
#
# Note that the flash files may also be programmed individually using nios2-flash-programmer as follows:
#
# nios2-flash-programmer -b 0x0 c5gt_fpga_bup.flash
# nios2-flash-programmer -b 0x0 c5gt_html.flash
# nios2-flash-programmer -b 0x0 ext_flash.flash
# nios2-flash-programmer -b 0x0 pfl_bits.flash
# nios2-flash-programmer -b 0x0 boot_code.flash
#
# For proper restore to work, the board FPGA should still also be one-time configured as described in 
# the User's Guide, entitled: "Restoring the Flash Device with the Factory Settings"
#